# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RamRoleAttachmentArgs', 'RamRoleAttachment']

@pulumi.input_type
class RamRoleAttachmentArgs:
    def __init__(__self__, *,
                 instance_id: pulumi.Input[builtins.str],
                 ram_role_name: pulumi.Input[builtins.str],
                 policy: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a RamRoleAttachment resource.
        :param pulumi.Input[builtins.str] instance_id: The ID of the instance.
        :param pulumi.Input[builtins.str] ram_role_name: The name of the instance RAM role.
        :param pulumi.Input[builtins.str] policy: The additional policy. When you attach an instance RAM role to instances, you can specify an additional policy to further limit the permissions of the role.
        """
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "ram_role_name", ram_role_name)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="ramRoleName")
    def ram_role_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the instance RAM role.
        """
        return pulumi.get(self, "ram_role_name")

    @ram_role_name.setter
    def ram_role_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "ram_role_name", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The additional policy. When you attach an instance RAM role to instances, you can specify an additional policy to further limit the permissions of the role.
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy", value)


@pulumi.input_type
class _RamRoleAttachmentState:
    def __init__(__self__, *,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 policy: Optional[pulumi.Input[builtins.str]] = None,
                 ram_role_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering RamRoleAttachment resources.
        :param pulumi.Input[builtins.str] instance_id: The ID of the instance.
        :param pulumi.Input[builtins.str] policy: The additional policy. When you attach an instance RAM role to instances, you can specify an additional policy to further limit the permissions of the role.
        :param pulumi.Input[builtins.str] ram_role_name: The name of the instance RAM role.
        """
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if ram_role_name is not None:
            pulumi.set(__self__, "ram_role_name", ram_role_name)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The additional policy. When you attach an instance RAM role to instances, you can specify an additional policy to further limit the permissions of the role.
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter(name="ramRoleName")
    def ram_role_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the instance RAM role.
        """
        return pulumi.get(self, "ram_role_name")

    @ram_role_name.setter
    def ram_role_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ram_role_name", value)


@pulumi.type_token("alicloud:ecs/ramRoleAttachment:RamRoleAttachment")
class RamRoleAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 policy: Optional[pulumi.Input[builtins.str]] = None,
                 ram_role_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a ECS Ram Role Attachment resource.

        Mount RAM role.

        For information about ECS Ram Role Attachment and how to use it, see [What is Ram Role Attachment](https://next.api.alibabacloud.com/document/Ecs/2014-05-26/AttachInstanceRamRole).

        > **NOTE:** Available since v1.250.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.get_zones(available_disk_category="cloud_efficiency",
            available_resource_creation="VSwitch")
        default_get_images = alicloud.ecs.get_images(most_recent=True,
            owners="system")
        default_get_instance_types = alicloud.ecs.get_instance_types(availability_zone=default.zones[0].id,
            image_id=default_get_images.images[0].id)
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        default_role = alicloud.ram.Role("default",
            name=f"{name}-{default_integer['result']}",
            document=\"\"\"\\x09\\x09{
        \\x09\\x09\\x09"Statement": [
        \\x09\\x09\\x09\\x09{
        \\x09\\x09\\x09\\x09\\x09"Action": "sts:AssumeRole",
        \\x09\\x09\\x09\\x09\\x09"Effect": "Allow",
        \\x09\\x09\\x09\\x09\\x09"Principal": {
        \\x09\\x09\\x09\\x09\\x09\\x09"Service": [
        \\x09\\x09\\x09\\x09\\x09\\x09\\x09"ecs.aliyuncs.com"
        \\x09\\x09\\x09\\x09\\x09\\x09]
        \\x09\\x09\\x09\\x09\\x09}
        \\x09\\x09\\x09\\x09}
        \\x09\\x09  \\x09],
        \\x09\\x09\\x09"Version": "1"
        \\x09\\x09}
        \"\"\",
            force=True)
        default_network = alicloud.vpc.Network("default",
            vpc_name=f"{name}-{default_integer['result']}",
            cidr_block="192.168.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vswitch_name=f"{name}-{default_integer['result']}",
            vpc_id=default_network.id,
            cidr_block="192.168.192.0/24",
            zone_id=default.zones[0].id)
        default_security_group = alicloud.ecs.SecurityGroup("default", vpc_id=default_network.id)
        default_instance = alicloud.ecs.Instance("default",
            image_id=default_get_images.images[0].id,
            instance_type=default_get_instance_types.instance_types[0].id,
            security_groups=[__item.id for __item in [default_security_group]],
            internet_charge_type="PayByTraffic",
            internet_max_bandwidth_out=10,
            availability_zone=default_get_instance_types.instance_types[0].availability_zones[0],
            instance_charge_type="PostPaid",
            system_disk_category="cloud_efficiency",
            vswitch_id=default_switch.id,
            instance_name=f"{name}-{default_integer['result']}")
        default_ram_role_attachment = alicloud.ecs.RamRoleAttachment("default",
            ram_role_name=default_role.id,
            instance_id=default_instance.id)
        ```

        ## Import

        ECS Ram Role Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ecs/ramRoleAttachment:RamRoleAttachment example <instance_id>:<ram_role_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] instance_id: The ID of the instance.
        :param pulumi.Input[builtins.str] policy: The additional policy. When you attach an instance RAM role to instances, you can specify an additional policy to further limit the permissions of the role.
        :param pulumi.Input[builtins.str] ram_role_name: The name of the instance RAM role.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RamRoleAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ECS Ram Role Attachment resource.

        Mount RAM role.

        For information about ECS Ram Role Attachment and how to use it, see [What is Ram Role Attachment](https://next.api.alibabacloud.com/document/Ecs/2014-05-26/AttachInstanceRamRole).

        > **NOTE:** Available since v1.250.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.get_zones(available_disk_category="cloud_efficiency",
            available_resource_creation="VSwitch")
        default_get_images = alicloud.ecs.get_images(most_recent=True,
            owners="system")
        default_get_instance_types = alicloud.ecs.get_instance_types(availability_zone=default.zones[0].id,
            image_id=default_get_images.images[0].id)
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        default_role = alicloud.ram.Role("default",
            name=f"{name}-{default_integer['result']}",
            document=\"\"\"\\x09\\x09{
        \\x09\\x09\\x09"Statement": [
        \\x09\\x09\\x09\\x09{
        \\x09\\x09\\x09\\x09\\x09"Action": "sts:AssumeRole",
        \\x09\\x09\\x09\\x09\\x09"Effect": "Allow",
        \\x09\\x09\\x09\\x09\\x09"Principal": {
        \\x09\\x09\\x09\\x09\\x09\\x09"Service": [
        \\x09\\x09\\x09\\x09\\x09\\x09\\x09"ecs.aliyuncs.com"
        \\x09\\x09\\x09\\x09\\x09\\x09]
        \\x09\\x09\\x09\\x09\\x09}
        \\x09\\x09\\x09\\x09}
        \\x09\\x09  \\x09],
        \\x09\\x09\\x09"Version": "1"
        \\x09\\x09}
        \"\"\",
            force=True)
        default_network = alicloud.vpc.Network("default",
            vpc_name=f"{name}-{default_integer['result']}",
            cidr_block="192.168.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vswitch_name=f"{name}-{default_integer['result']}",
            vpc_id=default_network.id,
            cidr_block="192.168.192.0/24",
            zone_id=default.zones[0].id)
        default_security_group = alicloud.ecs.SecurityGroup("default", vpc_id=default_network.id)
        default_instance = alicloud.ecs.Instance("default",
            image_id=default_get_images.images[0].id,
            instance_type=default_get_instance_types.instance_types[0].id,
            security_groups=[__item.id for __item in [default_security_group]],
            internet_charge_type="PayByTraffic",
            internet_max_bandwidth_out=10,
            availability_zone=default_get_instance_types.instance_types[0].availability_zones[0],
            instance_charge_type="PostPaid",
            system_disk_category="cloud_efficiency",
            vswitch_id=default_switch.id,
            instance_name=f"{name}-{default_integer['result']}")
        default_ram_role_attachment = alicloud.ecs.RamRoleAttachment("default",
            ram_role_name=default_role.id,
            instance_id=default_instance.id)
        ```

        ## Import

        ECS Ram Role Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ecs/ramRoleAttachment:RamRoleAttachment example <instance_id>:<ram_role_name>
        ```

        :param str resource_name: The name of the resource.
        :param RamRoleAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RamRoleAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 policy: Optional[pulumi.Input[builtins.str]] = None,
                 ram_role_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RamRoleAttachmentArgs.__new__(RamRoleAttachmentArgs)

            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["policy"] = policy
            if ram_role_name is None and not opts.urn:
                raise TypeError("Missing required property 'ram_role_name'")
            __props__.__dict__["ram_role_name"] = ram_role_name
        super(RamRoleAttachment, __self__).__init__(
            'alicloud:ecs/ramRoleAttachment:RamRoleAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            policy: Optional[pulumi.Input[builtins.str]] = None,
            ram_role_name: Optional[pulumi.Input[builtins.str]] = None) -> 'RamRoleAttachment':
        """
        Get an existing RamRoleAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] instance_id: The ID of the instance.
        :param pulumi.Input[builtins.str] policy: The additional policy. When you attach an instance RAM role to instances, you can specify an additional policy to further limit the permissions of the role.
        :param pulumi.Input[builtins.str] ram_role_name: The name of the instance RAM role.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RamRoleAttachmentState.__new__(_RamRoleAttachmentState)

        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["policy"] = policy
        __props__.__dict__["ram_role_name"] = ram_role_name
        return RamRoleAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def policy(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The additional policy. When you attach an instance RAM role to instances, you can specify an additional policy to further limit the permissions of the role.
        """
        return pulumi.get(self, "policy")

    @property
    @pulumi.getter(name="ramRoleName")
    def ram_role_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the instance RAM role.
        """
        return pulumi.get(self, "ram_role_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetFlowlogsResult',
    'AwaitableGetFlowlogsResult',
    'get_flowlogs',
    'get_flowlogs_output',
]

@pulumi.output_type
class GetFlowlogsResult:
    """
    A collection of values returned by getFlowlogs.
    """
    def __init__(__self__, cen_id=None, description=None, flow_log_id=None, flow_log_name=None, flow_log_version=None, flowlogs=None, id=None, ids=None, interval=None, log_store_name=None, name_regex=None, names=None, output_file=None, page_number=None, page_size=None, project_name=None, region_id=None, status=None, transit_router_id=None):
        if cen_id and not isinstance(cen_id, str):
            raise TypeError("Expected argument 'cen_id' to be a str")
        pulumi.set(__self__, "cen_id", cen_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if flow_log_id and not isinstance(flow_log_id, str):
            raise TypeError("Expected argument 'flow_log_id' to be a str")
        pulumi.set(__self__, "flow_log_id", flow_log_id)
        if flow_log_name and not isinstance(flow_log_name, str):
            raise TypeError("Expected argument 'flow_log_name' to be a str")
        pulumi.set(__self__, "flow_log_name", flow_log_name)
        if flow_log_version and not isinstance(flow_log_version, str):
            raise TypeError("Expected argument 'flow_log_version' to be a str")
        pulumi.set(__self__, "flow_log_version", flow_log_version)
        if flowlogs and not isinstance(flowlogs, list):
            raise TypeError("Expected argument 'flowlogs' to be a list")
        pulumi.set(__self__, "flowlogs", flowlogs)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if interval and not isinstance(interval, int):
            raise TypeError("Expected argument 'interval' to be a int")
        pulumi.set(__self__, "interval", interval)
        if log_store_name and not isinstance(log_store_name, str):
            raise TypeError("Expected argument 'log_store_name' to be a str")
        pulumi.set(__self__, "log_store_name", log_store_name)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if region_id and not isinstance(region_id, str):
            raise TypeError("Expected argument 'region_id' to be a str")
        pulumi.set(__self__, "region_id", region_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if transit_router_id and not isinstance(transit_router_id, str):
            raise TypeError("Expected argument 'transit_router_id' to be a str")
        pulumi.set(__self__, "transit_router_id", transit_router_id)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> Optional[builtins.str]:
        """
        The ID of Cen instance.
        """
        return pulumi.get(self, "cen_id")

    @property
    @pulumi.getter
    def description(self) -> Optional[builtins.str]:
        """
        The description of the flowlog.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="flowLogId")
    def flow_log_id(self) -> Optional[builtins.str]:
        """
        The ID of FlowLog.
        """
        return pulumi.get(self, "flow_log_id")

    @property
    @pulumi.getter(name="flowLogName")
    def flow_log_name(self) -> Optional[builtins.str]:
        """
        The name of the flowlog.
        """
        return pulumi.get(self, "flow_log_name")

    @property
    @pulumi.getter(name="flowLogVersion")
    def flow_log_version(self) -> Optional[builtins.str]:
        """
        (Available since v1.236.0) Flowlog Version.
        """
        return pulumi.get(self, "flow_log_version")

    @property
    @pulumi.getter
    def flowlogs(self) -> Sequence['outputs.GetFlowlogsFlowlogResult']:
        """
        A list of Flow Log Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "flowlogs")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of Flow Log IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def interval(self) -> Optional[builtins.int]:
        """
        (Available since v1.236.0) The duration of the capture window for the flow log to capture traffic. Unit: seconds. Valid values: **60** or **600 * *. Default value: **600 * *.
        """
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter(name="logStoreName")
    def log_store_name(self) -> Optional[builtins.str]:
        """
        The LogStore that stores the flowlog.
        """
        return pulumi.get(self, "log_store_name")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        A list of name of Flow Logs.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[builtins.int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[builtins.int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[builtins.str]:
        """
        The Project that stores the flowlog.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[builtins.str]:
        """
        (Available since v1.236.0) Region Id.
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        """
        The status of the flow log. Valid values:-**Active**: started.-**InActive**: not started.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> Optional[builtins.str]:
        """
        (Available since v1.236.0) Transit Router ID.
        """
        return pulumi.get(self, "transit_router_id")


class AwaitableGetFlowlogsResult(GetFlowlogsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFlowlogsResult(
            cen_id=self.cen_id,
            description=self.description,
            flow_log_id=self.flow_log_id,
            flow_log_name=self.flow_log_name,
            flow_log_version=self.flow_log_version,
            flowlogs=self.flowlogs,
            id=self.id,
            ids=self.ids,
            interval=self.interval,
            log_store_name=self.log_store_name,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size,
            project_name=self.project_name,
            region_id=self.region_id,
            status=self.status,
            transit_router_id=self.transit_router_id)


def get_flowlogs(cen_id: Optional[builtins.str] = None,
                 description: Optional[builtins.str] = None,
                 flow_log_id: Optional[builtins.str] = None,
                 flow_log_name: Optional[builtins.str] = None,
                 flow_log_version: Optional[builtins.str] = None,
                 ids: Optional[Sequence[builtins.str]] = None,
                 interval: Optional[builtins.int] = None,
                 log_store_name: Optional[builtins.str] = None,
                 name_regex: Optional[builtins.str] = None,
                 output_file: Optional[builtins.str] = None,
                 page_number: Optional[builtins.int] = None,
                 page_size: Optional[builtins.int] = None,
                 project_name: Optional[builtins.str] = None,
                 region_id: Optional[builtins.str] = None,
                 status: Optional[builtins.str] = None,
                 transit_router_id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFlowlogsResult:
    """
    This data source provides CEN flow logs available to the user.

    > **NOTE:** Available since v1.78.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud
    import pulumi_random as random

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "tf-example"
    default_integer = random.index.Integer("default",
        min=10000,
        max=99999)
    defaultc5kxy_c = alicloud.cen.Instance("defaultc5kxyC", cen_instance_name=name)
    default_vw2_u9u = alicloud.cen.TransitRouter("defaultVw2U9u", cen_id=defaultc5kxy_c.id)
    default_project = alicloud.log.Project("default",
        project_name=f"{name}-{default_integer['result']}",
        description="terraform-example")
    default_store = alicloud.log.Store("default",
        project_name=default_project.project_name,
        logstore_name=f"{name}-{default_integer['result']}",
        shard_count=3,
        auto_split=True,
        max_split_shard_count=60,
        append_meta=True)
    default_flow_log = alicloud.cen.FlowLog("default",
        project_name=default_store.project_name,
        flow_log_name=f"{name}-{default_integer['result']}",
        log_format_string="${srcaddr}${dstaddr}${bytes}",
        cen_id=defaultc5kxy_c.id,
        log_store_name=default_store.logstore_name,
        interval=600,
        status="Active",
        transit_router_id=default_vw2_u9u.transit_router_id,
        description="flowlog-resource-example-1")
    default = alicloud.cen.get_flowlogs_output(ids=[default_flow_log.id])
    pulumi.export("firstCenFlowlogId", default.flowlogs[0].id)
    ```


    :param builtins.str cen_id: The ID of Cen instance.
    :param builtins.str description: The description of the flowlog.
    :param builtins.str flow_log_id: The ID of FlowLog.
    :param builtins.str flow_log_name: The name of the flowlog.
    :param builtins.str flow_log_version: Flowlog Version.
    :param Sequence[builtins.str] ids: A list of Flow Log IDs.
    :param builtins.int interval: The duration of the capture window for the flow log to capture traffic. Unit: seconds. Valid values: **60** or **600 * *. Default value: **600 * *.
    :param builtins.str log_store_name: The LogStore that stores the flowlog.
    :param builtins.str name_regex: A regex string to filter results by Group Metric Rule name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.int page_number: Current page number.
    :param builtins.int page_size: Number of records per page.
    :param builtins.str project_name: The Project that stores the flowlog.
    :param builtins.str region_id: Region id
    :param builtins.str status: The status of the flow log. Valid values:-**Active**: started.-**InActive**: not started.
    :param builtins.str transit_router_id: Transit Router ID
    """
    __args__ = dict()
    __args__['cenId'] = cen_id
    __args__['description'] = description
    __args__['flowLogId'] = flow_log_id
    __args__['flowLogName'] = flow_log_name
    __args__['flowLogVersion'] = flow_log_version
    __args__['ids'] = ids
    __args__['interval'] = interval
    __args__['logStoreName'] = log_store_name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['projectName'] = project_name
    __args__['regionId'] = region_id
    __args__['status'] = status
    __args__['transitRouterId'] = transit_router_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cen/getFlowlogs:getFlowlogs', __args__, opts=opts, typ=GetFlowlogsResult).value

    return AwaitableGetFlowlogsResult(
        cen_id=pulumi.get(__ret__, 'cen_id'),
        description=pulumi.get(__ret__, 'description'),
        flow_log_id=pulumi.get(__ret__, 'flow_log_id'),
        flow_log_name=pulumi.get(__ret__, 'flow_log_name'),
        flow_log_version=pulumi.get(__ret__, 'flow_log_version'),
        flowlogs=pulumi.get(__ret__, 'flowlogs'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        interval=pulumi.get(__ret__, 'interval'),
        log_store_name=pulumi.get(__ret__, 'log_store_name'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'),
        project_name=pulumi.get(__ret__, 'project_name'),
        region_id=pulumi.get(__ret__, 'region_id'),
        status=pulumi.get(__ret__, 'status'),
        transit_router_id=pulumi.get(__ret__, 'transit_router_id'))
def get_flowlogs_output(cen_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        description: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        flow_log_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        flow_log_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        flow_log_version: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                        interval: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                        log_store_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        page_number: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                        page_size: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                        project_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        region_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        status: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        transit_router_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFlowlogsResult]:
    """
    This data source provides CEN flow logs available to the user.

    > **NOTE:** Available since v1.78.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud
    import pulumi_random as random

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "tf-example"
    default_integer = random.index.Integer("default",
        min=10000,
        max=99999)
    defaultc5kxy_c = alicloud.cen.Instance("defaultc5kxyC", cen_instance_name=name)
    default_vw2_u9u = alicloud.cen.TransitRouter("defaultVw2U9u", cen_id=defaultc5kxy_c.id)
    default_project = alicloud.log.Project("default",
        project_name=f"{name}-{default_integer['result']}",
        description="terraform-example")
    default_store = alicloud.log.Store("default",
        project_name=default_project.project_name,
        logstore_name=f"{name}-{default_integer['result']}",
        shard_count=3,
        auto_split=True,
        max_split_shard_count=60,
        append_meta=True)
    default_flow_log = alicloud.cen.FlowLog("default",
        project_name=default_store.project_name,
        flow_log_name=f"{name}-{default_integer['result']}",
        log_format_string="${srcaddr}${dstaddr}${bytes}",
        cen_id=defaultc5kxy_c.id,
        log_store_name=default_store.logstore_name,
        interval=600,
        status="Active",
        transit_router_id=default_vw2_u9u.transit_router_id,
        description="flowlog-resource-example-1")
    default = alicloud.cen.get_flowlogs_output(ids=[default_flow_log.id])
    pulumi.export("firstCenFlowlogId", default.flowlogs[0].id)
    ```


    :param builtins.str cen_id: The ID of Cen instance.
    :param builtins.str description: The description of the flowlog.
    :param builtins.str flow_log_id: The ID of FlowLog.
    :param builtins.str flow_log_name: The name of the flowlog.
    :param builtins.str flow_log_version: Flowlog Version.
    :param Sequence[builtins.str] ids: A list of Flow Log IDs.
    :param builtins.int interval: The duration of the capture window for the flow log to capture traffic. Unit: seconds. Valid values: **60** or **600 * *. Default value: **600 * *.
    :param builtins.str log_store_name: The LogStore that stores the flowlog.
    :param builtins.str name_regex: A regex string to filter results by Group Metric Rule name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.int page_number: Current page number.
    :param builtins.int page_size: Number of records per page.
    :param builtins.str project_name: The Project that stores the flowlog.
    :param builtins.str region_id: Region id
    :param builtins.str status: The status of the flow log. Valid values:-**Active**: started.-**InActive**: not started.
    :param builtins.str transit_router_id: Transit Router ID
    """
    __args__ = dict()
    __args__['cenId'] = cen_id
    __args__['description'] = description
    __args__['flowLogId'] = flow_log_id
    __args__['flowLogName'] = flow_log_name
    __args__['flowLogVersion'] = flow_log_version
    __args__['ids'] = ids
    __args__['interval'] = interval
    __args__['logStoreName'] = log_store_name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['projectName'] = project_name
    __args__['regionId'] = region_id
    __args__['status'] = status
    __args__['transitRouterId'] = transit_router_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cen/getFlowlogs:getFlowlogs', __args__, opts=opts, typ=GetFlowlogsResult)
    return __ret__.apply(lambda __response__: GetFlowlogsResult(
        cen_id=pulumi.get(__response__, 'cen_id'),
        description=pulumi.get(__response__, 'description'),
        flow_log_id=pulumi.get(__response__, 'flow_log_id'),
        flow_log_name=pulumi.get(__response__, 'flow_log_name'),
        flow_log_version=pulumi.get(__response__, 'flow_log_version'),
        flowlogs=pulumi.get(__response__, 'flowlogs'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        interval=pulumi.get(__response__, 'interval'),
        log_store_name=pulumi.get(__response__, 'log_store_name'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        page_number=pulumi.get(__response__, 'page_number'),
        page_size=pulumi.get(__response__, 'page_size'),
        project_name=pulumi.get(__response__, 'project_name'),
        region_id=pulumi.get(__response__, 'region_id'),
        status=pulumi.get(__response__, 'status'),
        transit_router_id=pulumi.get(__response__, 'transit_router_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDatabasesResult',
    'AwaitableGetDatabasesResult',
    'get_databases',
    'get_databases_output',
]

@pulumi.output_type
class GetDatabasesResult:
    """
    A collection of values returned by getDatabases.
    """
    def __init__(__self__, databases=None, db_cluster_id=None, id=None, name_regex=None, names=None):
        if databases and not isinstance(databases, list):
            raise TypeError("Expected argument 'databases' to be a list")
        pulumi.set(__self__, "databases", databases)
        if db_cluster_id and not isinstance(db_cluster_id, str):
            raise TypeError("Expected argument 'db_cluster_id' to be a str")
        pulumi.set(__self__, "db_cluster_id", db_cluster_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)

    @property
    @pulumi.getter
    def databases(self) -> Sequence['outputs.GetDatabasesDatabaseResult']:
        """
        A list of PolarDB cluster databases. Each element contains the following attributes:
        """
        return pulumi.get(self, "databases")

    @property
    @pulumi.getter(name="dbClusterId")
    def db_cluster_id(self) -> builtins.str:
        return pulumi.get(self, "db_cluster_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        database name of the cluster.
        """
        return pulumi.get(self, "names")


class AwaitableGetDatabasesResult(GetDatabasesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabasesResult(
            databases=self.databases,
            db_cluster_id=self.db_cluster_id,
            id=self.id,
            name_regex=self.name_regex,
            names=self.names)


def get_databases(db_cluster_id: Optional[builtins.str] = None,
                  name_regex: Optional[builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabasesResult:
    """
    The `polardb_get_databases` data source provides a collection of PolarDB cluster database available in Alibaba Cloud account.
    Filters support regular expression for the database name, searches by clusterId.

    > **NOTE:** Available since v1.70.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    this = alicloud.polardb.get_node_classes(db_type="MySQL",
        db_version="8.0",
        pay_type="PostPaid",
        category="Normal")
    default_network = alicloud.vpc.Network("default",
        vpc_name="terraform-example",
        cidr_block="172.16.0.0/16")
    default_switch = alicloud.vpc.Switch("default",
        vpc_id=default_network.id,
        cidr_block="172.16.0.0/24",
        zone_id=this.classes[0].zone_id,
        vswitch_name="terraform-example")
    cluster = alicloud.polardb.Cluster("cluster",
        db_type="MySQL",
        db_version="8.0",
        pay_type="PostPaid",
        db_node_count=2,
        db_node_class=this.classes[0].supported_engines[0].available_resources[0].db_node_class,
        vswitch_id=default_switch.id)
    polardb_clusters_ds = alicloud.polardb.get_clusters_output(description_regex=cluster.description,
        status="Running")
    default_database = alicloud.polardb.Database("default",
        db_cluster_id=polardb_clusters_ds.clusters[0].id,
        db_name=polardb_clusters_ds.apply(lambda polardb_clusters_ds: f"tfaccountpri_{polardb_clusters_ds.clusters[0].id}"),
        db_description="from terraform")
    default = pulumi.Output.all(
        polardb_clusters_ds=polardb_clusters_ds,
        db_name=default_database.db_name
    ).apply(lambda resolved_outputs: alicloud.polardb.get_databases_output(db_cluster_id=polardb_clusters_ds.clusters[0].id,
        name_regex=resolved_outputs['db_name']))

    pulumi.export("database", default.databases[0].db_name)
    ```


    :param builtins.str db_cluster_id: The polarDB cluster ID.
    :param builtins.str name_regex: A regex string to filter results by database name.
    """
    __args__ = dict()
    __args__['dbClusterId'] = db_cluster_id
    __args__['nameRegex'] = name_regex
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:polardb/getDatabases:getDatabases', __args__, opts=opts, typ=GetDatabasesResult).value

    return AwaitableGetDatabasesResult(
        databases=pulumi.get(__ret__, 'databases'),
        db_cluster_id=pulumi.get(__ret__, 'db_cluster_id'),
        id=pulumi.get(__ret__, 'id'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'))
def get_databases_output(db_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                         name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabasesResult]:
    """
    The `polardb_get_databases` data source provides a collection of PolarDB cluster database available in Alibaba Cloud account.
    Filters support regular expression for the database name, searches by clusterId.

    > **NOTE:** Available since v1.70.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    this = alicloud.polardb.get_node_classes(db_type="MySQL",
        db_version="8.0",
        pay_type="PostPaid",
        category="Normal")
    default_network = alicloud.vpc.Network("default",
        vpc_name="terraform-example",
        cidr_block="172.16.0.0/16")
    default_switch = alicloud.vpc.Switch("default",
        vpc_id=default_network.id,
        cidr_block="172.16.0.0/24",
        zone_id=this.classes[0].zone_id,
        vswitch_name="terraform-example")
    cluster = alicloud.polardb.Cluster("cluster",
        db_type="MySQL",
        db_version="8.0",
        pay_type="PostPaid",
        db_node_count=2,
        db_node_class=this.classes[0].supported_engines[0].available_resources[0].db_node_class,
        vswitch_id=default_switch.id)
    polardb_clusters_ds = alicloud.polardb.get_clusters_output(description_regex=cluster.description,
        status="Running")
    default_database = alicloud.polardb.Database("default",
        db_cluster_id=polardb_clusters_ds.clusters[0].id,
        db_name=polardb_clusters_ds.apply(lambda polardb_clusters_ds: f"tfaccountpri_{polardb_clusters_ds.clusters[0].id}"),
        db_description="from terraform")
    default = pulumi.Output.all(
        polardb_clusters_ds=polardb_clusters_ds,
        db_name=default_database.db_name
    ).apply(lambda resolved_outputs: alicloud.polardb.get_databases_output(db_cluster_id=polardb_clusters_ds.clusters[0].id,
        name_regex=resolved_outputs['db_name']))

    pulumi.export("database", default.databases[0].db_name)
    ```


    :param builtins.str db_cluster_id: The polarDB cluster ID.
    :param builtins.str name_regex: A regex string to filter results by database name.
    """
    __args__ = dict()
    __args__['dbClusterId'] = db_cluster_id
    __args__['nameRegex'] = name_regex
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:polardb/getDatabases:getDatabases', __args__, opts=opts, typ=GetDatabasesResult)
    return __ret__.apply(lambda __response__: GetDatabasesResult(
        databases=pulumi.get(__response__, 'databases'),
        db_cluster_id=pulumi.get(__response__, 'db_cluster_id'),
        id=pulumi.get(__response__, 'id'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['HttpsApplicationConfigurationArgs', 'HttpsApplicationConfiguration']

@pulumi.input_type
class HttpsApplicationConfigurationArgs:
    def __init__(__self__, *,
                 site_id: pulumi.Input[builtins.int],
                 alt_svc: Optional[pulumi.Input[builtins.str]] = None,
                 alt_svc_clear: Optional[pulumi.Input[builtins.str]] = None,
                 alt_svc_ma: Optional[pulumi.Input[builtins.str]] = None,
                 alt_svc_persist: Optional[pulumi.Input[builtins.str]] = None,
                 hsts: Optional[pulumi.Input[builtins.str]] = None,
                 hsts_include_subdomains: Optional[pulumi.Input[builtins.str]] = None,
                 hsts_max_age: Optional[pulumi.Input[builtins.str]] = None,
                 hsts_preload: Optional[pulumi.Input[builtins.str]] = None,
                 https_force: Optional[pulumi.Input[builtins.str]] = None,
                 https_force_code: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a HttpsApplicationConfiguration resource.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites API.
        :param pulumi.Input[builtins.str] alt_svc: Function switch, default off. Value range:
        :param pulumi.Input[builtins.str] alt_svc_clear: Alt-Svc whether The header contains the clear parameter. This parameter is disabled by default. Value range:
        :param pulumi.Input[builtins.str] alt_svc_ma: The effective time of the Alt-Svc, in seconds. The default value is 86400 seconds.
        :param pulumi.Input[builtins.str] alt_svc_persist: Alt-Svc whether The header contains the persist parameter. This parameter is disabled by default. Value range:
        :param pulumi.Input[builtins.str] hsts: Whether to enable HSTS. It is disabled by default. Value range:
        :param pulumi.Input[builtins.str] hsts_include_subdomains: Whether to include subdomains in HSTS is disabled by default. Value range:
        :param pulumi.Input[builtins.str] hsts_max_age: The expiration time of HSTS, in seconds.
        :param pulumi.Input[builtins.str] hsts_preload: Whether to enable HSTS preloading. It is disabled by default. Value range:
        :param pulumi.Input[builtins.str] https_force: Whether to enable forced HTTPS. It is disabled by default. Value range:
        :param pulumi.Input[builtins.str] https_force_code: Forced HTTPS jump status code, value range:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        pulumi.set(__self__, "site_id", site_id)
        if alt_svc is not None:
            pulumi.set(__self__, "alt_svc", alt_svc)
        if alt_svc_clear is not None:
            pulumi.set(__self__, "alt_svc_clear", alt_svc_clear)
        if alt_svc_ma is not None:
            pulumi.set(__self__, "alt_svc_ma", alt_svc_ma)
        if alt_svc_persist is not None:
            pulumi.set(__self__, "alt_svc_persist", alt_svc_persist)
        if hsts is not None:
            pulumi.set(__self__, "hsts", hsts)
        if hsts_include_subdomains is not None:
            pulumi.set(__self__, "hsts_include_subdomains", hsts_include_subdomains)
        if hsts_max_age is not None:
            pulumi.set(__self__, "hsts_max_age", hsts_max_age)
        if hsts_preload is not None:
            pulumi.set(__self__, "hsts_preload", hsts_preload)
        if https_force is not None:
            pulumi.set(__self__, "https_force", https_force)
        if https_force_code is not None:
            pulumi.set(__self__, "https_force_code", https_force_code)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        The site ID, which can be obtained by calling the ListSites API.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="altSvc")
    def alt_svc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Function switch, default off. Value range:
        """
        return pulumi.get(self, "alt_svc")

    @alt_svc.setter
    def alt_svc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "alt_svc", value)

    @property
    @pulumi.getter(name="altSvcClear")
    def alt_svc_clear(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Alt-Svc whether The header contains the clear parameter. This parameter is disabled by default. Value range:
        """
        return pulumi.get(self, "alt_svc_clear")

    @alt_svc_clear.setter
    def alt_svc_clear(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "alt_svc_clear", value)

    @property
    @pulumi.getter(name="altSvcMa")
    def alt_svc_ma(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The effective time of the Alt-Svc, in seconds. The default value is 86400 seconds.
        """
        return pulumi.get(self, "alt_svc_ma")

    @alt_svc_ma.setter
    def alt_svc_ma(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "alt_svc_ma", value)

    @property
    @pulumi.getter(name="altSvcPersist")
    def alt_svc_persist(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Alt-Svc whether The header contains the persist parameter. This parameter is disabled by default. Value range:
        """
        return pulumi.get(self, "alt_svc_persist")

    @alt_svc_persist.setter
    def alt_svc_persist(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "alt_svc_persist", value)

    @property
    @pulumi.getter
    def hsts(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable HSTS. It is disabled by default. Value range:
        """
        return pulumi.get(self, "hsts")

    @hsts.setter
    def hsts(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hsts", value)

    @property
    @pulumi.getter(name="hstsIncludeSubdomains")
    def hsts_include_subdomains(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to include subdomains in HSTS is disabled by default. Value range:
        """
        return pulumi.get(self, "hsts_include_subdomains")

    @hsts_include_subdomains.setter
    def hsts_include_subdomains(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hsts_include_subdomains", value)

    @property
    @pulumi.getter(name="hstsMaxAge")
    def hsts_max_age(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The expiration time of HSTS, in seconds.
        """
        return pulumi.get(self, "hsts_max_age")

    @hsts_max_age.setter
    def hsts_max_age(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hsts_max_age", value)

    @property
    @pulumi.getter(name="hstsPreload")
    def hsts_preload(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable HSTS preloading. It is disabled by default. Value range:
        """
        return pulumi.get(self, "hsts_preload")

    @hsts_preload.setter
    def hsts_preload(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hsts_preload", value)

    @property
    @pulumi.getter(name="httpsForce")
    def https_force(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable forced HTTPS. It is disabled by default. Value range:
        """
        return pulumi.get(self, "https_force")

    @https_force.setter
    def https_force(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "https_force", value)

    @property
    @pulumi.getter(name="httpsForceCode")
    def https_force_code(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Forced HTTPS jump status code, value range:
        """
        return pulumi.get(self, "https_force_code")

    @https_force_code.setter
    def https_force_code(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "https_force_code", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        - Match all incoming requests: value set to true
        - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)


@pulumi.input_type
class _HttpsApplicationConfigurationState:
    def __init__(__self__, *,
                 alt_svc: Optional[pulumi.Input[builtins.str]] = None,
                 alt_svc_clear: Optional[pulumi.Input[builtins.str]] = None,
                 alt_svc_ma: Optional[pulumi.Input[builtins.str]] = None,
                 alt_svc_persist: Optional[pulumi.Input[builtins.str]] = None,
                 config_id: Optional[pulumi.Input[builtins.int]] = None,
                 hsts: Optional[pulumi.Input[builtins.str]] = None,
                 hsts_include_subdomains: Optional[pulumi.Input[builtins.str]] = None,
                 hsts_max_age: Optional[pulumi.Input[builtins.str]] = None,
                 hsts_preload: Optional[pulumi.Input[builtins.str]] = None,
                 https_force: Optional[pulumi.Input[builtins.str]] = None,
                 https_force_code: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering HttpsApplicationConfiguration resources.
        :param pulumi.Input[builtins.str] alt_svc: Function switch, default off. Value range:
        :param pulumi.Input[builtins.str] alt_svc_clear: Alt-Svc whether The header contains the clear parameter. This parameter is disabled by default. Value range:
        :param pulumi.Input[builtins.str] alt_svc_ma: The effective time of the Alt-Svc, in seconds. The default value is 86400 seconds.
        :param pulumi.Input[builtins.str] alt_svc_persist: Alt-Svc whether The header contains the persist parameter. This parameter is disabled by default. Value range:
        :param pulumi.Input[builtins.int] config_id: Config Id
        :param pulumi.Input[builtins.str] hsts: Whether to enable HSTS. It is disabled by default. Value range:
        :param pulumi.Input[builtins.str] hsts_include_subdomains: Whether to include subdomains in HSTS is disabled by default. Value range:
        :param pulumi.Input[builtins.str] hsts_max_age: The expiration time of HSTS, in seconds.
        :param pulumi.Input[builtins.str] hsts_preload: Whether to enable HSTS preloading. It is disabled by default. Value range:
        :param pulumi.Input[builtins.str] https_force: Whether to enable forced HTTPS. It is disabled by default. Value range:
        :param pulumi.Input[builtins.str] https_force_code: Forced HTTPS jump status code, value range:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites API.
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        if alt_svc is not None:
            pulumi.set(__self__, "alt_svc", alt_svc)
        if alt_svc_clear is not None:
            pulumi.set(__self__, "alt_svc_clear", alt_svc_clear)
        if alt_svc_ma is not None:
            pulumi.set(__self__, "alt_svc_ma", alt_svc_ma)
        if alt_svc_persist is not None:
            pulumi.set(__self__, "alt_svc_persist", alt_svc_persist)
        if config_id is not None:
            pulumi.set(__self__, "config_id", config_id)
        if hsts is not None:
            pulumi.set(__self__, "hsts", hsts)
        if hsts_include_subdomains is not None:
            pulumi.set(__self__, "hsts_include_subdomains", hsts_include_subdomains)
        if hsts_max_age is not None:
            pulumi.set(__self__, "hsts_max_age", hsts_max_age)
        if hsts_preload is not None:
            pulumi.set(__self__, "hsts_preload", hsts_preload)
        if https_force is not None:
            pulumi.set(__self__, "https_force", https_force)
        if https_force_code is not None:
            pulumi.set(__self__, "https_force_code", https_force_code)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)

    @property
    @pulumi.getter(name="altSvc")
    def alt_svc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Function switch, default off. Value range:
        """
        return pulumi.get(self, "alt_svc")

    @alt_svc.setter
    def alt_svc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "alt_svc", value)

    @property
    @pulumi.getter(name="altSvcClear")
    def alt_svc_clear(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Alt-Svc whether The header contains the clear parameter. This parameter is disabled by default. Value range:
        """
        return pulumi.get(self, "alt_svc_clear")

    @alt_svc_clear.setter
    def alt_svc_clear(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "alt_svc_clear", value)

    @property
    @pulumi.getter(name="altSvcMa")
    def alt_svc_ma(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The effective time of the Alt-Svc, in seconds. The default value is 86400 seconds.
        """
        return pulumi.get(self, "alt_svc_ma")

    @alt_svc_ma.setter
    def alt_svc_ma(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "alt_svc_ma", value)

    @property
    @pulumi.getter(name="altSvcPersist")
    def alt_svc_persist(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Alt-Svc whether The header contains the persist parameter. This parameter is disabled by default. Value range:
        """
        return pulumi.get(self, "alt_svc_persist")

    @alt_svc_persist.setter
    def alt_svc_persist(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "alt_svc_persist", value)

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Config Id
        """
        return pulumi.get(self, "config_id")

    @config_id.setter
    def config_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "config_id", value)

    @property
    @pulumi.getter
    def hsts(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable HSTS. It is disabled by default. Value range:
        """
        return pulumi.get(self, "hsts")

    @hsts.setter
    def hsts(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hsts", value)

    @property
    @pulumi.getter(name="hstsIncludeSubdomains")
    def hsts_include_subdomains(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to include subdomains in HSTS is disabled by default. Value range:
        """
        return pulumi.get(self, "hsts_include_subdomains")

    @hsts_include_subdomains.setter
    def hsts_include_subdomains(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hsts_include_subdomains", value)

    @property
    @pulumi.getter(name="hstsMaxAge")
    def hsts_max_age(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The expiration time of HSTS, in seconds.
        """
        return pulumi.get(self, "hsts_max_age")

    @hsts_max_age.setter
    def hsts_max_age(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hsts_max_age", value)

    @property
    @pulumi.getter(name="hstsPreload")
    def hsts_preload(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable HSTS preloading. It is disabled by default. Value range:
        """
        return pulumi.get(self, "hsts_preload")

    @hsts_preload.setter
    def hsts_preload(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hsts_preload", value)

    @property
    @pulumi.getter(name="httpsForce")
    def https_force(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable forced HTTPS. It is disabled by default. Value range:
        """
        return pulumi.get(self, "https_force")

    @https_force.setter
    def https_force(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "https_force", value)

    @property
    @pulumi.getter(name="httpsForceCode")
    def https_force_code(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Forced HTTPS jump status code, value range:
        """
        return pulumi.get(self, "https_force_code")

    @https_force_code.setter
    def https_force_code(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "https_force_code", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        - Match all incoming requests: value set to true
        - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The site ID, which can be obtained by calling the ListSites API.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)


@pulumi.type_token("alicloud:esa/httpsApplicationConfiguration:HttpsApplicationConfiguration")
class HttpsApplicationConfiguration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alt_svc: Optional[pulumi.Input[builtins.str]] = None,
                 alt_svc_clear: Optional[pulumi.Input[builtins.str]] = None,
                 alt_svc_ma: Optional[pulumi.Input[builtins.str]] = None,
                 alt_svc_persist: Optional[pulumi.Input[builtins.str]] = None,
                 hsts: Optional[pulumi.Input[builtins.str]] = None,
                 hsts_include_subdomains: Optional[pulumi.Input[builtins.str]] = None,
                 hsts_max_age: Optional[pulumi.Input[builtins.str]] = None,
                 hsts_preload: Optional[pulumi.Input[builtins.str]] = None,
                 https_force: Optional[pulumi.Input[builtins.str]] = None,
                 https_force_code: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Provides a ESA Https Application Configuration resource.

        For information about ESA Https Application Configuration and how to use it, see [What is Https Application Configuration](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateHttpsApplicationConfiguration).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_site = alicloud.esa.Site("default",
            site_name="httpsapplicationconfiguration.example.com",
            instance_id=default.sites[0].instance_id,
            coverage="domestic",
            access_type="NS")
        default_https_application_configuration = alicloud.esa.HttpsApplicationConfiguration("default",
            hsts_max_age="31536000",
            alt_svc_clear="off",
            rule="http.host eq \\"video.example.com\\"",
            https_force="off",
            alt_svc_ma="86400",
            hsts="off",
            rule_name="rule_example",
            rule_enable="off",
            site_id=default_site.id,
            alt_svc_persist="off",
            hsts_preload="off",
            hsts_include_subdomains="off",
            alt_svc="off",
            https_force_code="301",
            site_version=0)
        ```

        ## Import

        ESA Https Application Configuration can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/httpsApplicationConfiguration:HttpsApplicationConfiguration example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] alt_svc: Function switch, default off. Value range:
        :param pulumi.Input[builtins.str] alt_svc_clear: Alt-Svc whether The header contains the clear parameter. This parameter is disabled by default. Value range:
        :param pulumi.Input[builtins.str] alt_svc_ma: The effective time of the Alt-Svc, in seconds. The default value is 86400 seconds.
        :param pulumi.Input[builtins.str] alt_svc_persist: Alt-Svc whether The header contains the persist parameter. This parameter is disabled by default. Value range:
        :param pulumi.Input[builtins.str] hsts: Whether to enable HSTS. It is disabled by default. Value range:
        :param pulumi.Input[builtins.str] hsts_include_subdomains: Whether to include subdomains in HSTS is disabled by default. Value range:
        :param pulumi.Input[builtins.str] hsts_max_age: The expiration time of HSTS, in seconds.
        :param pulumi.Input[builtins.str] hsts_preload: Whether to enable HSTS preloading. It is disabled by default. Value range:
        :param pulumi.Input[builtins.str] https_force: Whether to enable forced HTTPS. It is disabled by default. Value range:
        :param pulumi.Input[builtins.str] https_force_code: Forced HTTPS jump status code, value range:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites API.
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HttpsApplicationConfigurationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Https Application Configuration resource.

        For information about ESA Https Application Configuration and how to use it, see [What is Https Application Configuration](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateHttpsApplicationConfiguration).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_site = alicloud.esa.Site("default",
            site_name="httpsapplicationconfiguration.example.com",
            instance_id=default.sites[0].instance_id,
            coverage="domestic",
            access_type="NS")
        default_https_application_configuration = alicloud.esa.HttpsApplicationConfiguration("default",
            hsts_max_age="31536000",
            alt_svc_clear="off",
            rule="http.host eq \\"video.example.com\\"",
            https_force="off",
            alt_svc_ma="86400",
            hsts="off",
            rule_name="rule_example",
            rule_enable="off",
            site_id=default_site.id,
            alt_svc_persist="off",
            hsts_preload="off",
            hsts_include_subdomains="off",
            alt_svc="off",
            https_force_code="301",
            site_version=0)
        ```

        ## Import

        ESA Https Application Configuration can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/httpsApplicationConfiguration:HttpsApplicationConfiguration example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param HttpsApplicationConfigurationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HttpsApplicationConfigurationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alt_svc: Optional[pulumi.Input[builtins.str]] = None,
                 alt_svc_clear: Optional[pulumi.Input[builtins.str]] = None,
                 alt_svc_ma: Optional[pulumi.Input[builtins.str]] = None,
                 alt_svc_persist: Optional[pulumi.Input[builtins.str]] = None,
                 hsts: Optional[pulumi.Input[builtins.str]] = None,
                 hsts_include_subdomains: Optional[pulumi.Input[builtins.str]] = None,
                 hsts_max_age: Optional[pulumi.Input[builtins.str]] = None,
                 hsts_preload: Optional[pulumi.Input[builtins.str]] = None,
                 https_force: Optional[pulumi.Input[builtins.str]] = None,
                 https_force_code: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HttpsApplicationConfigurationArgs.__new__(HttpsApplicationConfigurationArgs)

            __props__.__dict__["alt_svc"] = alt_svc
            __props__.__dict__["alt_svc_clear"] = alt_svc_clear
            __props__.__dict__["alt_svc_ma"] = alt_svc_ma
            __props__.__dict__["alt_svc_persist"] = alt_svc_persist
            __props__.__dict__["hsts"] = hsts
            __props__.__dict__["hsts_include_subdomains"] = hsts_include_subdomains
            __props__.__dict__["hsts_max_age"] = hsts_max_age
            __props__.__dict__["hsts_preload"] = hsts_preload
            __props__.__dict__["https_force"] = https_force
            __props__.__dict__["https_force_code"] = https_force_code
            __props__.__dict__["rule"] = rule
            __props__.__dict__["rule_enable"] = rule_enable
            __props__.__dict__["rule_name"] = rule_name
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["site_version"] = site_version
            __props__.__dict__["config_id"] = None
        super(HttpsApplicationConfiguration, __self__).__init__(
            'alicloud:esa/httpsApplicationConfiguration:HttpsApplicationConfiguration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alt_svc: Optional[pulumi.Input[builtins.str]] = None,
            alt_svc_clear: Optional[pulumi.Input[builtins.str]] = None,
            alt_svc_ma: Optional[pulumi.Input[builtins.str]] = None,
            alt_svc_persist: Optional[pulumi.Input[builtins.str]] = None,
            config_id: Optional[pulumi.Input[builtins.int]] = None,
            hsts: Optional[pulumi.Input[builtins.str]] = None,
            hsts_include_subdomains: Optional[pulumi.Input[builtins.str]] = None,
            hsts_max_age: Optional[pulumi.Input[builtins.str]] = None,
            hsts_preload: Optional[pulumi.Input[builtins.str]] = None,
            https_force: Optional[pulumi.Input[builtins.str]] = None,
            https_force_code: Optional[pulumi.Input[builtins.str]] = None,
            rule: Optional[pulumi.Input[builtins.str]] = None,
            rule_enable: Optional[pulumi.Input[builtins.str]] = None,
            rule_name: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            site_version: Optional[pulumi.Input[builtins.int]] = None) -> 'HttpsApplicationConfiguration':
        """
        Get an existing HttpsApplicationConfiguration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] alt_svc: Function switch, default off. Value range:
        :param pulumi.Input[builtins.str] alt_svc_clear: Alt-Svc whether The header contains the clear parameter. This parameter is disabled by default. Value range:
        :param pulumi.Input[builtins.str] alt_svc_ma: The effective time of the Alt-Svc, in seconds. The default value is 86400 seconds.
        :param pulumi.Input[builtins.str] alt_svc_persist: Alt-Svc whether The header contains the persist parameter. This parameter is disabled by default. Value range:
        :param pulumi.Input[builtins.int] config_id: Config Id
        :param pulumi.Input[builtins.str] hsts: Whether to enable HSTS. It is disabled by default. Value range:
        :param pulumi.Input[builtins.str] hsts_include_subdomains: Whether to include subdomains in HSTS is disabled by default. Value range:
        :param pulumi.Input[builtins.str] hsts_max_age: The expiration time of HSTS, in seconds.
        :param pulumi.Input[builtins.str] hsts_preload: Whether to enable HSTS preloading. It is disabled by default. Value range:
        :param pulumi.Input[builtins.str] https_force: Whether to enable forced HTTPS. It is disabled by default. Value range:
        :param pulumi.Input[builtins.str] https_force_code: Forced HTTPS jump status code, value range:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites API.
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HttpsApplicationConfigurationState.__new__(_HttpsApplicationConfigurationState)

        __props__.__dict__["alt_svc"] = alt_svc
        __props__.__dict__["alt_svc_clear"] = alt_svc_clear
        __props__.__dict__["alt_svc_ma"] = alt_svc_ma
        __props__.__dict__["alt_svc_persist"] = alt_svc_persist
        __props__.__dict__["config_id"] = config_id
        __props__.__dict__["hsts"] = hsts
        __props__.__dict__["hsts_include_subdomains"] = hsts_include_subdomains
        __props__.__dict__["hsts_max_age"] = hsts_max_age
        __props__.__dict__["hsts_preload"] = hsts_preload
        __props__.__dict__["https_force"] = https_force
        __props__.__dict__["https_force_code"] = https_force_code
        __props__.__dict__["rule"] = rule
        __props__.__dict__["rule_enable"] = rule_enable
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["site_version"] = site_version
        return HttpsApplicationConfiguration(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="altSvc")
    def alt_svc(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Function switch, default off. Value range:
        """
        return pulumi.get(self, "alt_svc")

    @property
    @pulumi.getter(name="altSvcClear")
    def alt_svc_clear(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Alt-Svc whether The header contains the clear parameter. This parameter is disabled by default. Value range:
        """
        return pulumi.get(self, "alt_svc_clear")

    @property
    @pulumi.getter(name="altSvcMa")
    def alt_svc_ma(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The effective time of the Alt-Svc, in seconds. The default value is 86400 seconds.
        """
        return pulumi.get(self, "alt_svc_ma")

    @property
    @pulumi.getter(name="altSvcPersist")
    def alt_svc_persist(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Alt-Svc whether The header contains the persist parameter. This parameter is disabled by default. Value range:
        """
        return pulumi.get(self, "alt_svc_persist")

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> pulumi.Output[builtins.int]:
        """
        Config Id
        """
        return pulumi.get(self, "config_id")

    @property
    @pulumi.getter
    def hsts(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to enable HSTS. It is disabled by default. Value range:
        """
        return pulumi.get(self, "hsts")

    @property
    @pulumi.getter(name="hstsIncludeSubdomains")
    def hsts_include_subdomains(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to include subdomains in HSTS is disabled by default. Value range:
        """
        return pulumi.get(self, "hsts_include_subdomains")

    @property
    @pulumi.getter(name="hstsMaxAge")
    def hsts_max_age(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The expiration time of HSTS, in seconds.
        """
        return pulumi.get(self, "hsts_max_age")

    @property
    @pulumi.getter(name="hstsPreload")
    def hsts_preload(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to enable HSTS preloading. It is disabled by default. Value range:
        """
        return pulumi.get(self, "hsts_preload")

    @property
    @pulumi.getter(name="httpsForce")
    def https_force(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to enable forced HTTPS. It is disabled by default. Value range:
        """
        return pulumi.get(self, "https_force")

    @property
    @pulumi.getter(name="httpsForceCode")
    def https_force_code(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Forced HTTPS jump status code, value range:
        """
        return pulumi.get(self, "https_force_code")

    @property
    @pulumi.getter
    def rule(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        - Match all incoming requests: value set to true
        - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        """
        return pulumi.get(self, "rule_enable")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        The site ID, which can be obtained by calling the ListSites API.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        return pulumi.get(self, "site_version")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAlertRobotsResult',
    'AwaitableGetAlertRobotsResult',
    'get_alert_robots',
    'get_alert_robots_output',
]

@pulumi.output_type
class GetAlertRobotsResult:
    """
    A collection of values returned by getAlertRobots.
    """
    def __init__(__self__, alert_robot_name=None, id=None, ids=None, name_regex=None, names=None, output_file=None, robot_type=None, robots=None):
        if alert_robot_name and not isinstance(alert_robot_name, str):
            raise TypeError("Expected argument 'alert_robot_name' to be a str")
        pulumi.set(__self__, "alert_robot_name", alert_robot_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if robot_type and not isinstance(robot_type, str):
            raise TypeError("Expected argument 'robot_type' to be a str")
        pulumi.set(__self__, "robot_type", robot_type)
        if robots and not isinstance(robots, list):
            raise TypeError("Expected argument 'robots' to be a list")
        pulumi.set(__self__, "robots", robots)

    @property
    @pulumi.getter(name="alertRobotName")
    def alert_robot_name(self) -> Optional[builtins.str]:
        return pulumi.get(self, "alert_robot_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of Alert Robot IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        A list of Alert Robot names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="robotType")
    def robot_type(self) -> Optional[builtins.str]:
        """
        The type of the robot.
        """
        return pulumi.get(self, "robot_type")

    @property
    @pulumi.getter
    def robots(self) -> Sequence['outputs.GetAlertRobotsRobotResult']:
        """
        A list of Arms Alert Robots. Each element contains the following attributes:
        """
        return pulumi.get(self, "robots")


class AwaitableGetAlertRobotsResult(GetAlertRobotsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAlertRobotsResult(
            alert_robot_name=self.alert_robot_name,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            robot_type=self.robot_type,
            robots=self.robots)


def get_alert_robots(alert_robot_name: Optional[builtins.str] = None,
                     ids: Optional[Sequence[builtins.str]] = None,
                     name_regex: Optional[builtins.str] = None,
                     output_file: Optional[builtins.str] = None,
                     robot_type: Optional[builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAlertRobotsResult:
    """
    This data source provides the Arms Alert Robots of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.237.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.arms.AlertRobot("default",
        alert_robot_name="my-AlertRobot",
        robot_type="wechat",
        robot_addr="https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=1c704e23")
    name_regex = alicloud.arms.get_alert_robots_output(alert_robot_name=default.alert_robot_name)
    pulumi.export("armsAlertRobotId", name_regex.robots[0].id)
    ```


    :param builtins.str alert_robot_name: The robot name.
    :param Sequence[builtins.str] ids: A list of Alert Robot IDs.
    :param builtins.str name_regex: A regex string to filter results by Alert Robot name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str robot_type: The robot type.
    """
    __args__ = dict()
    __args__['alertRobotName'] = alert_robot_name
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['robotType'] = robot_type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:arms/getAlertRobots:getAlertRobots', __args__, opts=opts, typ=GetAlertRobotsResult).value

    return AwaitableGetAlertRobotsResult(
        alert_robot_name=pulumi.get(__ret__, 'alert_robot_name'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        robot_type=pulumi.get(__ret__, 'robot_type'),
        robots=pulumi.get(__ret__, 'robots'))
def get_alert_robots_output(alert_robot_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                            ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                            name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                            output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                            robot_type: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAlertRobotsResult]:
    """
    This data source provides the Arms Alert Robots of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.237.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.arms.AlertRobot("default",
        alert_robot_name="my-AlertRobot",
        robot_type="wechat",
        robot_addr="https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=1c704e23")
    name_regex = alicloud.arms.get_alert_robots_output(alert_robot_name=default.alert_robot_name)
    pulumi.export("armsAlertRobotId", name_regex.robots[0].id)
    ```


    :param builtins.str alert_robot_name: The robot name.
    :param Sequence[builtins.str] ids: A list of Alert Robot IDs.
    :param builtins.str name_regex: A regex string to filter results by Alert Robot name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str robot_type: The robot type.
    """
    __args__ = dict()
    __args__['alertRobotName'] = alert_robot_name
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['robotType'] = robot_type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:arms/getAlertRobots:getAlertRobots', __args__, opts=opts, typ=GetAlertRobotsResult)
    return __ret__.apply(lambda __response__: GetAlertRobotsResult(
        alert_robot_name=pulumi.get(__response__, 'alert_robot_name'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        robot_type=pulumi.get(__response__, 'robot_type'),
        robots=pulumi.get(__response__, 'robots')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ImageTransformArgs', 'ImageTransform']

@pulumi.input_type
class ImageTransformArgs:
    def __init__(__self__, *,
                 site_id: pulumi.Input[builtins.int],
                 enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a ImageTransform resource.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites API.
        :param pulumi.Input[builtins.str] enable: Indicates whether the image transformations feature is enabled. Valid values:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        pulumi.set(__self__, "site_id", site_id)
        if enable is not None:
            pulumi.set(__self__, "enable", enable)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        The site ID, which can be obtained by calling the ListSites API.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter
    def enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Indicates whether the image transformations feature is enabled. Valid values:
        """
        return pulumi.get(self, "enable")

    @enable.setter
    def enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "enable", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        - Match all incoming requests: value set to true
        - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)


@pulumi.input_type
class _ImageTransformState:
    def __init__(__self__, *,
                 config_id: Optional[pulumi.Input[builtins.int]] = None,
                 enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering ImageTransform resources.
        :param pulumi.Input[builtins.int] config_id: Config Id
        :param pulumi.Input[builtins.str] enable: Indicates whether the image transformations feature is enabled. Valid values:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites API.
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        if config_id is not None:
            pulumi.set(__self__, "config_id", config_id)
        if enable is not None:
            pulumi.set(__self__, "enable", enable)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Config Id
        """
        return pulumi.get(self, "config_id")

    @config_id.setter
    def config_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "config_id", value)

    @property
    @pulumi.getter
    def enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Indicates whether the image transformations feature is enabled. Valid values:
        """
        return pulumi.get(self, "enable")

    @enable.setter
    def enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "enable", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        - Match all incoming requests: value set to true
        - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The site ID, which can be obtained by calling the ListSites API.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)


@pulumi.type_token("alicloud:esa/imageTransform:ImageTransform")
class ImageTransform(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Provides a ESA Image Transform resource.

        For information about ESA Image Transform and how to use it, see [What is Image Transform](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateImageTransform).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_site = alicloud.esa.Site("default",
            site_name="imagetransform.tf.com",
            instance_id=default.sites[0].instance_id,
            coverage="domestic",
            access_type="NS")
        default_image_transform = alicloud.esa.ImageTransform("default",
            rule="http.host eq \\"video.example.com\\"",
            site_version=0,
            rule_name="rule_example",
            site_id=default_site.id,
            rule_enable="off",
            enable="off")
        ```

        ## Import

        ESA Image Transform can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/imageTransform:ImageTransform example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] enable: Indicates whether the image transformations feature is enabled. Valid values:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites API.
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ImageTransformArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Image Transform resource.

        For information about ESA Image Transform and how to use it, see [What is Image Transform](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateImageTransform).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_site = alicloud.esa.Site("default",
            site_name="imagetransform.tf.com",
            instance_id=default.sites[0].instance_id,
            coverage="domestic",
            access_type="NS")
        default_image_transform = alicloud.esa.ImageTransform("default",
            rule="http.host eq \\"video.example.com\\"",
            site_version=0,
            rule_name="rule_example",
            site_id=default_site.id,
            rule_enable="off",
            enable="off")
        ```

        ## Import

        ESA Image Transform can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/imageTransform:ImageTransform example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param ImageTransformArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ImageTransformArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ImageTransformArgs.__new__(ImageTransformArgs)

            __props__.__dict__["enable"] = enable
            __props__.__dict__["rule"] = rule
            __props__.__dict__["rule_enable"] = rule_enable
            __props__.__dict__["rule_name"] = rule_name
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["site_version"] = site_version
            __props__.__dict__["config_id"] = None
        super(ImageTransform, __self__).__init__(
            'alicloud:esa/imageTransform:ImageTransform',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config_id: Optional[pulumi.Input[builtins.int]] = None,
            enable: Optional[pulumi.Input[builtins.str]] = None,
            rule: Optional[pulumi.Input[builtins.str]] = None,
            rule_enable: Optional[pulumi.Input[builtins.str]] = None,
            rule_name: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            site_version: Optional[pulumi.Input[builtins.int]] = None) -> 'ImageTransform':
        """
        Get an existing ImageTransform resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] config_id: Config Id
        :param pulumi.Input[builtins.str] enable: Indicates whether the image transformations feature is enabled. Valid values:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the ListSites API.
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ImageTransformState.__new__(_ImageTransformState)

        __props__.__dict__["config_id"] = config_id
        __props__.__dict__["enable"] = enable
        __props__.__dict__["rule"] = rule
        __props__.__dict__["rule_enable"] = rule_enable
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["site_version"] = site_version
        return ImageTransform(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> pulumi.Output[builtins.int]:
        """
        Config Id
        """
        return pulumi.get(self, "config_id")

    @property
    @pulumi.getter
    def enable(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Indicates whether the image transformations feature is enabled. Valid values:
        """
        return pulumi.get(self, "enable")

    @property
    @pulumi.getter
    def rule(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        - Match all incoming requests: value set to true
        - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        """
        return pulumi.get(self, "rule_enable")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        The site ID, which can be obtained by calling the ListSites API.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        return pulumi.get(self, "site_version")

